@@ -20,6 +20,7 @@
 #include "stellarsolver.h"
 #include "sep/extract.h"
 #include "qmath.h"
+#include <QMutexLocker>
 
 //CFitsio Includes
 #include <fitsio.h>
@@ -46,7 +47,7 @@ InternalExtractorSolver::InternalExtractorSolver(ProcessType pType, ExtractorTyp
 
 InternalExtractorSolver::~InternalExtractorSolver()
 {
-    cancelSEP(); // Just in case it has not shut down
+    waitSEP(); // Just in case it has not shut down
     if(downSampledBuffer)
     {
         delete [] downSampledBuffer;
@@ -68,7 +69,7 @@ InternalExtractorSolver::~InternalExtractorSolver()
 //This is the abort method.  For the internal solver it sets a cancel variable. It quits the thread.  And it cancels any SEP threads that are in progress.
 void InternalExtractorSolver::abort()
 {
-    cancelSEP();
+    waitSEP();
     quit();
 
     thejob.bp.cancelled = TRUE;
@@ -77,16 +78,19 @@ void InternalExtractorSolver::abort()
     m_WasAborted = true;
 }
 
-void InternalExtractorSolver::cancelSEP()
+void InternalExtractorSolver::waitSEP()
 {
+    QMutexLocker locker(&futuresMutex);
+    if (futures.empty())
+        return;
+
     for (auto &oneFuture : futures)
     {
         if(oneFuture.isRunning())
-        {
-             oneFuture.cancel();
-             oneFuture.waitForFinished();
-        }
+            oneFuture.waitForFinished();
     }
+
+    futures.clear();
 }
 
 //This method generates child solvers with the options of the current solver
@@ -184,35 +188,31 @@ void InternalExtractorSolver::cleanupTempFiles()
     //There are NO temp files anymore for the internal SEP or Astrometry builds!!!
 }
 
-void InternalExtractorSolver::allocateDataBuffer(float *data, uint32_t x, uint32_t y, uint32_t w, uint32_t h)
+bool InternalExtractorSolver::allocateDataBuffer(float *data, uint32_t x, uint32_t y, uint32_t w, uint32_t h)
 {
     switch (m_Statistics.dataType)
     {
         case SEP_TBYTE:
-            getFloatBuffer<uint8_t>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<uint8_t>(data, x, y, w, h);
         case TSHORT:
-            getFloatBuffer<int16_t>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<int16_t>(data, x, y, w, h);
         case TUSHORT:
-            getFloatBuffer<uint16_t>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<uint16_t>(data, x, y, w, h);
         case TLONG:
-            getFloatBuffer<int32_t>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<int32_t>(data, x, y, w, h);
         case TULONG:
-            getFloatBuffer<uint32_t>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<uint32_t>(data, x, y, w, h);
         case TFLOAT:
-            getFloatBuffer<float>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<float>(data, x, y, w, h);
         case TDOUBLE:
-            getFloatBuffer<double>(data, x, y, w, h);
-            break;
+            return getFloatBuffer<double>(data, x, y, w, h);
         default:
             delete [] data;
             data = 0;
+            return false;
     }
+
+    return false;
 }
 
 namespace
@@ -228,14 +228,16 @@ void computeMargin(uint32_t x1, uint32_t y1, uint32_t x2, uint32_t y2,
     // Figure out the start and start margins.
     // Make sure these are signed operations.
     int tempStartX = ((int) x1) - ((int)margin);
-    if (tempStartX < 0) {
-      tempStartX = 0;
+    if (tempStartX < 0)
+    {
+        tempStartX = 0;
     }
     *startX = tempStartX;
 
     int tempStartY = ((int) y1) - ((int)margin);
-    if (tempStartY < 0) {
-      tempStartY = 0;
+    if (tempStartY < 0)
+    {
+        tempStartY = 0;
     }
     *startY = tempStartY;
 
@@ -255,19 +257,36 @@ void computeMargin(uint32_t x1, uint32_t y1, uint32_t x2, uint32_t y2,
 //I used KStars and the SEP website as a guide for creating these functions
 int InternalExtractorSolver::runSEPExtractor()
 {
+    QMutexLocker locker(&futuresMutex);
     if(convFilter.size() == 0)
     {
         emit logOutput("No convFilter included.");
         return -1;
     }
+
+    // Double check nothing else is running.
+    //waitSEP();
+
     emit logOutput("+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++");
     emit logOutput("Starting Internal StellarSolver Star Extractor with the " + m_ActiveParameters.listName + " profile . . .");
     //Only merge image channels if it is an RGB image and we are either averaging or integrating the channels
     if(m_Statistics.channels == 3 && (m_ColorChannel == FITSImage::AVERAGE_RGB || m_ColorChannel == FITSImage::INTEGRATED_RGB))
-        mergeImageChannels();
+    {
+        if (mergeImageChannels() == false)
+        {
+            emit logOutput("Merging image channels failed.");
+            return -1;
+        }
+    }
     //Only downsample images before SEP if the Sextraction is being used for plate solving
     if(m_ProcessType == SOLVE && m_SolverType == SOLVER_STELLARSOLVER && m_ActiveParameters.downsample != 1)
-        downsampleImage(m_ActiveParameters.downsample);
+    {
+        if (downsampleImage(m_ActiveParameters.downsample) == false)
+        {
+            emit logOutput("Downsampling failed.");
+            return -1;
+        }
+    }
     uint32_t x = 0, y = 0;
     uint32_t w = m_Statistics.width, h = m_Statistics.height;
     uint32_t raw_w = m_Statistics.width, raw_h = m_Statistics.height;
@@ -287,17 +306,17 @@ int InternalExtractorSolver::runSEPExtractor()
     // i.e. not including the margins. The endpoints are inclusive. Later, we will not include
     // stars detected in the margins, e.g. points where x < innerStartX or x > innerEndX.
     // Similar for Y.
-    class StartupOffset {
-    public:
-      int startX = 0, startY = 0, width = 0, height = 0;
-      int innerStartX = 0, innerStartY = 0, innerEndX = 0, innerEndY = 0;
-      StartupOffset(int x, int y, int w, int h, int inX1, int inY1, int inX2, int inY2)
-        :startX(x), startY(y), width(w), height(h),
-         innerStartX(inX1), innerStartY(inY1), innerEndX(inX2), innerEndY(inY2) {}
+    class StartupOffset
+    {
+        public:
+            int startX = 0, startY = 0, width = 0, height = 0;
+            int innerStartX = 0, innerStartY = 0, innerEndX = 0, innerEndY = 0;
+            StartupOffset(int x, int y, int w, int h, int inX1, int inY1, int inX2, int inY2)
+                : startX(x), startY(y), width(w), height(h),
+                  innerStartX(inX1), innerStartY(inY1), innerEndX(inX2), innerEndY(inY2) {}
     };
 
-    QList<float *> dataBuffers;
-    futures.clear();
+    QVector<float *> dataBuffers;
     QList<StartupOffset> startupOffsets;
     QList<FITSImage::Background> backgrounds;
 
@@ -310,9 +329,9 @@ int InternalExtractorSolver::runSEPExtractor()
     // used to 50 (e.g. corresponding to a 100-pixel-wide star).
     int DEFAULT_MARGIN = m_ActiveParameters.maxSize / 2;
     if (DEFAULT_MARGIN <= 20)
-      DEFAULT_MARGIN = 20;
+        DEFAULT_MARGIN = 20;
     else if (DEFAULT_MARGIN > 50)
-      DEFAULT_MARGIN = 50;
+        DEFAULT_MARGIN = 50;
 
     // Only partition if:
     // We have 2 or more threads.
@@ -356,15 +375,21 @@ int InternalExtractorSolver::runSEPExtractor()
                 const uint32_t rawEndY = rawStartY + H_PARTITION_SIZE + offsetH;
 
                 uint32_t startX, startY, subWidth, subHeight;
-                computeMargin(rawStartX, rawStartY, rawEndX-1, rawEndY-1,
+                computeMargin(rawStartX, rawStartY, rawEndX - 1, rawEndY - 1,
                               m_Statistics.width, m_Statistics.height, DEFAULT_MARGIN,
                               &startX, &startY, &subWidth, &subHeight);
 
                 startupOffsets.append(StartupOffset(startX, startY, subWidth, subHeight,
-                                                    rawStartX, rawStartY, rawEndX-1, rawEndY-1));
+                                                    rawStartX, rawStartY, rawEndX - 1, rawEndY - 1));
 
-                auto * data = new float[subWidth * subHeight];
-                allocateDataBuffer(data, startX, startY, subWidth, subHeight);
+                auto *data = new float[subWidth * subHeight];
+                if (allocateDataBuffer(data, startX, startY, subWidth, subHeight) == false)
+                {
+                    for (auto *buffer : dataBuffers)
+                        delete [] buffer;
+                    emit logOutput("Failed to allocate memory.");
+                    return -1;
+                }
                 dataBuffers.append(data);
                 FITSImage::Background tempBackground;
                 backgrounds.append(tempBackground);
@@ -388,29 +413,29 @@ int InternalExtractorSolver::runSEPExtractor()
         // In this case, there is no partitioning, but it is still possible that margins apply.
         // E.g. a subframe rectangle with enough space around it to have margins.
         uint32_t startX, startY, subWidth, subHeight;
-        computeMargin(x, y, x+w-1, y+h-1, m_Statistics.width, m_Statistics.height, DEFAULT_MARGIN,
+        computeMargin(x, y, x + w - 1, y + h - 1, m_Statistics.width, m_Statistics.height, DEFAULT_MARGIN,
                       &startX, &startY, &subWidth, &subHeight);
 
-        auto * data = new float[subWidth * subHeight];
-        allocateDataBuffer(data, startX, startY, subWidth, subHeight);
+        auto *data = new float[subWidth * subHeight];
+        if (allocateDataBuffer(data, startX, startY, subWidth, subHeight) == false)
+        {
+            for (auto *buffer : dataBuffers)
+                delete [] buffer;
+            emit logOutput("Failed to allocate memory.");
+            return -1;
+        }
         dataBuffers.append(data);
-        startupOffsets.append(StartupOffset(startX, startY, subWidth, subHeight, x, y, x+w-1, y+h-1));
+        startupOffsets.append(StartupOffset(startX, startY, subWidth, subHeight, x, y, x + w - 1, y + h - 1));
         FITSImage::Background tempBackground;
         backgrounds.append(tempBackground);
 
         ImageParams parameters = {data, subWidth, subHeight, 0, 0, subWidth, subHeight, static_cast<uint32_t>(m_ActiveParameters.initialKeep), &backgrounds[backgrounds.size() - 1]};
         futures.append(QtConcurrent::run(this, &InternalExtractorSolver::extractPartition, parameters));
     }
-    bool isCancelled = false;
 
     for (auto &oneFuture : futures)
     {
         oneFuture.waitForFinished();
-        if(oneFuture.isCanceled())
-        {
-            isCancelled = true;
-            continue;
-        }
         QList<FITSImage::Star> partitionStars = oneFuture.result();
         QList<FITSImage::Star> acceptedStars;
         if (!startupOffsets.empty())
@@ -420,12 +445,12 @@ int InternalExtractorSolver::runSEPExtractor()
             const int startY = oneOffset.startY;
             for (auto &oneStar : partitionStars)
             {
-              // Don't use stars from the margins (they're detected in other partitions).
-              if (oneStar.x < (oneOffset.innerStartX - startX) ||
-                  oneStar.y < (oneOffset.innerStartY - startY) ||
-                  oneStar.x > (oneOffset.innerEndX   - startX) ||
-                  oneStar.y > (oneOffset.innerEndY   - startY))
-                  continue;
+                // Don't use stars from the margins (they're detected in other partitions).
+                if (oneStar.x < (oneOffset.innerStartX - startX) ||
+                        oneStar.y < (oneOffset.innerStartY - startY) ||
+                        oneStar.x > (oneOffset.innerEndX   - startX) ||
+                        oneStar.y > (oneOffset.innerEndY   - startY))
+                    continue;
                 oneStar.x += startX;
                 oneStar.y += startY;
                 acceptedStars.append(oneStar);
@@ -433,15 +458,6 @@ int InternalExtractorSolver::runSEPExtractor()
         }
         m_ExtractedStars.append(acceptedStars);
     }
-    if(isCancelled)
-    {
-        for (auto * buffer : dataBuffers)
-            delete [] buffer;
-        dataBuffers.clear();
-        futures.clear();
-        m_HasExtracted = false;
-        return 1;
-    }
 
     double sumGlobal = 0, sumRmsSq = 0;
     for (const auto &bg : qAsConst(backgrounds))
@@ -565,7 +581,8 @@ QList<FITSImage::Star> InternalExtractorSolver::extractPartition(const ImagePara
     extractor.reset(new Extract());
     // #4 Source Extraction
     // Note that we set deblend_cont = 1.0 to turn off deblending.
-    const double extractionThreshold = m_ActiveParameters.threshold_bg_multiple * bkg->globalrms + m_ActiveParameters.threshold_offset;
+    const double extractionThreshold = m_ActiveParameters.threshold_bg_multiple * bkg->globalrms +
+                                       m_ActiveParameters.threshold_offset;
     //fprintf(stderr, "Using %.1f =  %.1f * %.1f + %.1f\n", extractionThreshold, m_ActiveParameters.threshold_bg_multiple, bkg->globalrms,  m_ActiveParameters.threshold_offset);
     status = extractor->sep_extract(&im, extractionThreshold, SEP_THRESH_ABS, m_ActiveParameters.minarea,
                                     convFilter.data(),
@@ -804,9 +821,10 @@ void InternalExtractorSolver::applyStarFilters(QList<FITSImage::Star> &starList)
 }
 
 template <typename T>
-void InternalExtractorSolver::getFloatBuffer(float * buffer, int x, int y, int w, int h)
+bool InternalExtractorSolver::getFloatBuffer(float * buffer, int x, int y, int w, int h)
 {
-    int channelShift = (m_Statistics.channels < 3 || usingDownsampledImage || usingMergedChannelImage) ? 0 : ( m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel * m_ColorChannel );
+    int channelShift = (m_Statistics.channels < 3 || usingDownsampledImage
+                        || usingMergedChannelImage) ? 0 : ( m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel * m_ColorChannel );
     auto * rawBuffer = reinterpret_cast<T const *>(m_ImageBuffer + channelShift);
     float * floatPtr = buffer;
 
@@ -821,41 +839,35 @@ void InternalExtractorSolver::getFloatBuffer(float * buffer, int x, int y, int w
             *floatPtr++ = rawBuffer[offset + x1];
         }
     }
+
+    return true;
 }
 
-void InternalExtractorSolver::downsampleImage(int d)
+bool InternalExtractorSolver::downsampleImage(int d)
 {
     switch (m_Statistics.dataType)
     {
         case SEP_TBYTE:
-            downSampleImageType<uint8_t>(d);
-            break;
+            return downSampleImageType<uint8_t>(d);
         case TSHORT:
-            downSampleImageType<int16_t>(d);
-            break;
+            return downSampleImageType<int16_t>(d);
         case TUSHORT:
-            downSampleImageType<uint16_t>(d);
-            break;
+            return downSampleImageType<uint16_t>(d);
         case TLONG:
-            downSampleImageType<int32_t>(d);
-            break;
+            return downSampleImageType<int32_t>(d);
         case TULONG:
-            downSampleImageType<uint32_t>(d);
-            break;
+            return downSampleImageType<uint32_t>(d);
         case TFLOAT:
-            downSampleImageType<float>(d);
-            break;
+            return downSampleImageType<float>(d);
         case TDOUBLE:
-            downSampleImageType<double>(d);
-            break;
+            return downSampleImageType<double>(d);
         default:
-            return;
+            return false;
     }
-
 }
 
 template <typename T>
-void InternalExtractorSolver::downSampleImageType(int d)
+bool InternalExtractorSolver::downSampleImageType(int d)
 {
     int w = m_Statistics.width;
     int h = m_Statistics.height;
@@ -865,7 +877,8 @@ void InternalExtractorSolver::downSampleImageType(int d)
     if(downSampledBuffer)
         delete [] downSampledBuffer;
     downSampledBuffer = new uint8_t[newBufferSize];
-    int channelShift = ( m_Statistics.channels < 3 || usingMergedChannelImage) ? 0 : ( m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel * m_ColorChannel );
+    int channelShift = ( m_Statistics.channels < 3
+                         || usingMergedChannelImage) ? 0 : ( m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel * m_ColorChannel );
     auto * sourceBuffer = reinterpret_cast<T const *>(m_ImageBuffer + channelShift);
     auto * destinationBuffer = reinterpret_cast<T *>(downSampledBuffer);
 
@@ -906,52 +919,49 @@ void InternalExtractorSolver::downSampleImageType(int d)
         scalehi *= d;
     }
     usingDownsampledImage = true;
+    return true;
 }
 
-void InternalExtractorSolver::mergeImageChannels()
+bool InternalExtractorSolver::mergeImageChannels()
 {
     switch (m_Statistics.dataType)
     {
         case SEP_TBYTE:
-            mergeImageChannelsType<uint8_t>();
-            break;
+            return mergeImageChannelsType<uint8_t>();
         case TSHORT:
-            mergeImageChannelsType<int16_t>();
-            break;
+            return mergeImageChannelsType<int16_t>();
         case TUSHORT:
-            mergeImageChannelsType<uint16_t>();
-            break;
+            return mergeImageChannelsType<uint16_t>();
         case TLONG:
-            mergeImageChannelsType<int32_t>();
-            break;
+            return mergeImageChannelsType<int32_t>();
         case TULONG:
-            mergeImageChannelsType<uint32_t>();
-            break;
+            return mergeImageChannelsType<uint32_t>();
         case TFLOAT:
-            mergeImageChannelsType<float>();
-            break;
+            return mergeImageChannelsType<float>();
         case TDOUBLE:
-            mergeImageChannelsType<double>();
-            break;
+            return mergeImageChannelsType<double>();
         default:
-            return;
+            return false;
     }
 
 }
 
 template <typename T>
-void InternalExtractorSolver::mergeImageChannelsType()
+bool InternalExtractorSolver::mergeImageChannelsType()
 {
     if(m_Statistics.channels != 3)
-        return;
+        return false;
     if(m_ColorChannel != FITSImage::INTEGRATED_RGB && m_ColorChannel != FITSImage::AVERAGE_RGB)
-        return;
-    int w = m_Statistics.width;
-    int h = m_Statistics.height;
-    int nextChannel = m_Statistics.samples_per_channel;
-    int channelSize = m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel;
+        return false;
+
+    auto w = m_Statistics.width;
+    auto h = m_Statistics.height;
+    auto nextChannel = m_Statistics.samples_per_channel;
+    auto channelSize = m_Statistics.samples_per_channel * m_Statistics.bytesPerPixel;
+
     if(mergedChannelBuffer)
         delete [] mergedChannelBuffer;
+
     mergedChannelBuffer = new uint8_t[channelSize];
     auto * source = reinterpret_cast<T const *>(m_ImageBuffer);
     auto * dest = reinterpret_cast<T *>(mergedChannelBuffer);
@@ -968,11 +978,13 @@ void InternalExtractorSolver::mergeImageChannelsType()
                 total = source[r] + source[g] + source[b];
             if(m_ColorChannel == FITSImage::AVERAGE_RGB)
                 total = (source[r] + source[g] + source[b]) / 3.0;
-            dest[ x + y * w ] = (T) total;
+            dest[ x + y * w ] = static_cast<T>(total);
         }
     }
+
     m_ImageBuffer = mergedChannelBuffer;
     usingMergedChannelImage = true;
+    return true;
 }
 
 //This method prepares the job file.  It is based upon the methods parse_job_from_qfits_header and engine_read_job_file in engine.c of astrometry.net
@@ -1174,7 +1186,7 @@ int InternalExtractorSolver::runInternalSolver()
         //This sets the depths for the job.
         if (!il_size(engine->default_depths))
         {
-            for(int i = 10; i < 210; i+=10)
+            for(int i = 10; i < 210; i += 10)
                 il_append(engine->default_depths, i);
         }
         if (il_size(job->depths) == 0)
