@@ -50,7 +50,7 @@ int Extract::arraybuffer_init(arraybuffer *buf, void *arr, int dtype, int w, int
                               int bufw, int bufh)
 {
     int status, yl;
-    status = RETURN_OK;
+    //status = RETURN_OK; //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
 
     /* data info */
     buf->dptr = reinterpret_cast<unsigned char *>(arr);
@@ -113,8 +113,10 @@ void Extract::arraybuffer_readline(arraybuffer *buf)
 
 void Extract::arraybuffer_free(arraybuffer *buf)
 {
-    free(buf->bptr);
-    buf->bptr = NULL;
+    if(buf && buf->bptr){    //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+        free(buf->bptr);
+        buf->bptr = NULL;
+    }
 }
 
 /* apply_mask_line: Apply the mask to the image and noise buffers.
@@ -185,7 +187,7 @@ int Extract::sep_extract(sep_image *image, float thresh, int thresh_type,
     char              errtext[512];
     sep_catalog       *cat;
 
-    status = RETURN_OK;
+    //status = RETURN_OK; //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
     pixel = NULL;
     convnorm = NULL;
     scan = wscan = cdscan = dummyscan = NULL;
@@ -198,7 +200,7 @@ int Extract::sep_extract(sep_image *image, float thresh, int thresh_type,
     finalobjlist = NULL;
     survives = NULL;
     cat = NULL;
-    convn = 0;
+    //convn = 0; //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
     sum = 0.0;
     w = image->w;
     h = image->h;
@@ -701,8 +703,8 @@ int Extract::sep_extract(sep_image *image, float thresh, int thresh_type,
             if (status != RETURN_OK)
                 goto exit;
         }
-
-        QMALLOC(survives, int, finalobjlist->nobj, status);
+        if(finalobjlist->nobj > 0) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning, in case nobj is 0 or less.
+            QMALLOC(survives, int, finalobjlist->nobj, status);
         clean(finalobjlist, clean_param, survives);
     }
 
@@ -716,35 +718,56 @@ exit:
     {
         if(finalobjlist->obj)
             free(finalobjlist->obj);
+        finalobjlist->obj = 0;   //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
         if(finalobjlist->plist)
             free(finalobjlist->plist);
+        finalobjlist->plist = 0; //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
         free(finalobjlist);
+        finalobjlist = 0;        //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     }
     free(pixel);
+    pixel = 0;                   //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(info);
+    info = 0;                    //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(store);
+    store = 0;                   //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(marker);
-    free(dummyscan);
+    marker = 0;                  //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(psstack);
+    psstack = 0;                 //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(start);
+    start = 0;                   //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(end);
+    end = 0;                     //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(survives);
+    survives = 0;                //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     arraybuffer_free(&dbuf);
     if (image->noise)
         arraybuffer_free(&nbuf);
     if (image->mask)
         arraybuffer_free(&mbuf);
-    if (conv)
+    if (conv){
         free(convnorm);
+        convnorm = 0;            //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
+    }
     if (filter_type == SEP_FILTER_MATCHED)
     {
         free(sigscan);
+        sigscan = 0;             //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
         free(workscan);
+        workscan = 0;            //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     }
 
     /* free cdscan if we didn't do it on the last `yl` line */
     if (conv && (cdscan != dummyscan))
+    {
         free(cdscan);
+        cdscan = 0;              //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
+    }
+
+    //# Modified by Hy Murveit for the StellarSolver Internal Library, possible bug. Moved free(dummyscan) to here from earlier since it was referenced in the if above.
+    free(dummyscan);
+    dummyscan = 0;
 
     if (status != RETURN_OK)
     {
@@ -768,7 +791,7 @@ int Extract::sortit(infostruct *info, objliststruct *objlist, int minarea, objli
     objliststruct objlistout, *objlist2;
     int i, status;
 
-    status = RETURN_OK;
+    //status = RETURN_OK;  //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
     objlistout.obj = NULL;
     objlistout.plist = NULL;
     objlistout.nobj = objlistout.npix = 0;
@@ -818,7 +841,9 @@ int Extract::sortit(infostruct *info, objliststruct *objlist, int minarea, objli
 
 exit:
     free(objlistout.plist);
+    objlistout.plist = 0;  //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     free(objlistout.obj);
+    objlistout.obj = 0;    //# Added by Hy Murveit for the StellarSolver Internal Library for memory safety.
     return status;
 }
 
@@ -1012,6 +1037,9 @@ int Extract::convert_to_catalog(objliststruct *objlist, int *survives, sep_catal
     else
         nobj = objlist->nobj;
 
+    if(nobj ==0) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning, if nobj is 0, we don't want to set all this up.
+        return 1;
+
     /* allocate catalog fields */
     cat->nobj = nobj;
     QMALLOC(cat->thresh, float, nobj, status);
