@@ -44,7 +44,11 @@ StellarSolver::StellarSolver(ProcessType type, const FITSImage::Statistic &image
 
 StellarSolver::~StellarSolver()
 {
+    // These lines make sure that before the StellarSolver is deleted, all parallel threads (if any) are shut down
+    for(auto &solver : parallelSolvers)
+      disconnect(solver, &ExtractorSolver::finished, this, &StellarSolver::finishParallelSolve);
 
+    abortAndWait();
 }
 
 void StellarSolver::registerMetaTypes()
@@ -531,6 +535,9 @@ int StellarSolver::whichSolver(ExtractorSolver *solver)
 //This slot listens for signals from the child solvers that they are in fact done with the solve
 void StellarSolver::finishParallelSolve(int success)
 {
+    bool emitReady = false;
+    bool emitFinished = false;
+
     m_ParallelSolversFinishedCount++;
     ExtractorSolver *reportingSolver = qobject_cast<ExtractorSolver*>(sender());
     if(!reportingSolver)
@@ -566,7 +573,7 @@ void StellarSolver::finishParallelSolve(int success)
         }
         m_HasSolved = true;
         m_ExtractorSolver->cleanupTempFiles();
-        emit ready();
+        emitReady = true;
     }
     else
     {
@@ -579,13 +586,16 @@ void StellarSolver::finishParallelSolve(int success)
         m_isRunning = false;
         if(!m_HasSolved){
             m_HasFailed = true;
-            emit ready(); //Since this was emitted earlier if it had solved
+            emitReady = true; //Since this was emitted earlier if it had been solved
         }
         qDeleteAll(parallelSolvers);
         parallelSolvers.clear();
         m_ExtractorSolver->cleanupTempFiles();
-        emit finished();
+        emitFinished=true;
     }
+
+    if (emitReady) emit ready();
+    if (emitFinished) emit finished();
 }
 
 QString StellarSolver::raString(double ra)
@@ -625,14 +635,20 @@ bool StellarSolver::pixelToWCS(const QPointF &pixelPoint, FITSImage::wcs_point &
 //This is the abort method.  It works in different ways for the different solvers.
 void StellarSolver::abort()
 {
-  for(auto &solver : parallelSolvers) {
+  for(auto &solver : parallelSolvers)
       solver->abort();
-      solver->wait();
-  }
-  if(m_ExtractorSolver) {
+  if(m_ExtractorSolver)
       m_ExtractorSolver->abort();
+}
+
+//This is the abort and wait method, it is useful if you want the solver to be all shut down before moving on
+void StellarSolver::abortAndWait()
+{
+  abort();
+  for(auto &solver : parallelSolvers)
+      solver->wait();
+  if(m_ExtractorSolver)
       m_ExtractorSolver->wait();
-  }
 }
 
 //This method checks all the solvers and the internal running boolean to determine if anything is running.
